# -*- coding: utf-8 -*-
"""
Created on Tue Apr 16 00:00:59 2013

@author: Marek
"""

import vtk
import wx
from vtk.wx.wxVTKRenderWindowInteractor import wxVTKRenderWindowInteractor
from wx._core import EVT_SLIDER

APP_SIZE_X = 400
APP_SIZE_Y = 400

class MyRenderingWindow(wx.Frame):
    def __init__(self, parent, id1, title):
        wx.Frame.__init__(self, parent, id1, title, size=(APP_SIZE_X, APP_SIZE_Y))
        self.widget = wxVTKRenderWindowInteractor(self, -1, size = (APP_SIZE_X, APP_SIZE_Y) )

        self.lightSliderR = wx.Slider(self, value = 50, minValue = 0.0, maxValue = 255)
        self.lightSliderG = wx.Slider(self, value = 50, minValue = 0.0, maxValue = 255)
        self.lightSliderB = wx.Slider(self, value = 50, minValue = 0.0, maxValue = 255)
        self.Bind(EVT_SLIDER, self.OnSlider)
        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(self.widget,1, wx.ALIGN_CENTRE|wx.ALL)
        sizer.Add(self.lightSliderR,0.5,wx.ALIGN_CENTRE|wx.ALL)
        sizer.Add(self.lightSliderG,0.5,wx.ALIGN_CENTRE|wx.ALL)
        sizer.Add(self.lightSliderB,0.5,wx.ALIGN_CENTRE|wx.ALL)
        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        self.Fit()
        
        # create a rendering window and renderer
        ren = vtk.vtkRenderer()
        self.widget.GetRenderWindow().AddRenderer(ren)
         
        # Setup four points
        points = vtk.vtkPoints()
        points.InsertNextPoint(0.0, 0.0, 0.0)
        points.InsertNextPoint(1.0, 0.0, 0.0)
        points.InsertNextPoint(1.0, 1.0, 0.0)
        points.InsertNextPoint(0.0, 1.0, 0.0)

        # Create the polygon
        polygon = vtk.vtkPolygon()
        polygon.GetPointIds().SetNumberOfIds(4) #make a quad
        polygon.GetPointIds().SetId(0, 0)
        polygon.GetPointIds().SetId(1, 1)
        polygon.GetPointIds().SetId(2, 2)
        polygon.GetPointIds().SetId(3, 3)
        
        # Add the polygon to a list of polygons
        polygons = vtk.vtkCellArray()
        polygons.InsertNextCell(polygon)


        # Create a PolyData
        polygonPolyData = vtk.vtkPolyData()
        polygonPolyData.SetPoints(points)
        polygonPolyData.SetPolys(polygons)    
             
        # Create a mapper and actor
        mapper = vtk.vtkPolyDataMapper()
        mapper.SetInput(polygonPolyData)
         
        actor = vtk.vtkActor()
        actor.SetMapper(mapper)
        
        self.lSource = vtk.vtkLight() 
        self.lSource.SetLightTypeToCameraLight()
        self.lSource.SetColor(self.GetSlidersValues())
        
        # assign actor to the renderer
        ren.AddActor(actor)
        ren.AddLight(self.lSource) 
    def OnSlider(self, event):
        self.lSource.SetColor(self.GetSlidersValues())
        self.widget.Render()
        
    def GetSlidersValues(self):
        return float(self.lightSliderR.GetValue())/100.0, float(self.lightSliderG.GetValue())/100.0, float(self.lightSliderB.GetValue())/100.0
app = wx.App(0)
temp = MyRenderingWindow(None,-1, title = "Win")
temp.Show()
app.MainLoop()